==> spirit_hub-0.1.1.28.tar.gz: spirit_hub-0.1.1.28/app/overrides/channel.rb <==
# frozen_string_literal: true

Channel.prepend(Turbo::Broadcastable)
Channel.class_eval do
  field :archived, type: Mongoid::Boolean, default: false
  field :waiting_for_bot, type: Mongoid::Boolean, default: false

  has_many :favorites

  scope :unarchived, -> { where(archived: false) }
  scope :latest, -> { order(created_at: :desc) }
  scope :user_channels, ->(user) { where(responsible: user.id) }
  scope :created_today, -> { where(:created_at.gt => 1.days.ago) }
  scope :created_yesterday, -> { where(created_at: 2.days.ago...1.days.ago) }
  scope :created_last_week, -> { where(created_at: 7.days.ago...3.days.ago) }
  scope :created_last_month, -> { where(created_at: 1.month.ago..1.week.ago) }
  scope :created_older_than_last_month, -> { where(:created_at.lt => 1.month.ago) }

  scope :not_favorite, ->(user) { where(:id.nin => user.favorite_channel_ids) }
  scope :today_not_favorite, ->(user) { created_today.not_favorite(user).unarchived.latest }
  scope :yesterday_not_favorite, ->(user) { created_yesterday.not_favorite(user).unarchived.latest }
  scope :last_week_not_favorite, ->(user) { created_last_week.not_favorite(user).unarchived.latest }
  scope :last_month_not_favorite_not_last_week, ->(user) { created_last_month.not_favorite(user).unarchived }
  scope :older_message_not_favorite_not_last_month, ->(user) { created_older_than_last_month.not_favorite(user).unarchived }

  after_save :update_ui

  def update_ui
    broadcast_rename if saved_change_to_name?
    broadcast_waiting_for_bot if saved_change_to_waiting_for_bot?
  end

  private

  def broadcast_rename
    Turbo::StreamsChannel.broadcast_replace_later_to(
      "channel_name_#{id}",
      target: "channel_name_#{id}",
      html: <<~HTML
        <span id="channel_name">
          #{name.truncate(30)}
        </span>
      HTML
    )
  end

  def broadcast_waiting_for_bot
    broadcast_append_to "channel_waiting_for_bot_#{id}",
                        target: "channel_waiting_for_bot_#{id}",
                        renderable: SpinnerComponent.new(active: waiting_for_bot, size: :md, color: 'text-spirit-primary')
  end

  def suppressed_turbo_broadcasts?
    false
  end
end

==> spirit_hub-1.0.0.5.tar.gz: spirit_hub-1.0.0.5/app/overrides/channel.rb <==
# frozen_string_literal: true

Channel.prepend(Turbo::Broadcastable)
Channel.class_eval do # rubocop:disable Metrics/BlockLength
  field :archived, type: Mongoid::Boolean, default: false
  field :waiting_for_bot, type: Mongoid::Boolean, default: false

  has_many :favorites

  belongs_to :upload, optional: true

  scope :unarchived, -> { where(archived: false) }
  scope :latest, -> { order(created_at: :desc) }
  scope :not_comment, -> { where(:key.nin => [/_comments_/]) }
  scope :user_channels, ->(user) { where(responsible: user.id).not_comment }
  scope :created_today, -> { where(:created_at.gt => 1.days.ago) }
  scope :created_yesterday, -> { where(created_at: 2.days.ago...1.days.ago) }
  scope :created_last_week, -> { where(created_at: 7.days.ago...3.days.ago) }
  scope :created_last_month, -> { where(created_at: 1.month.ago..1.week.ago) }
  scope :created_older_than_last_month, -> { where(:created_at.lt => 1.month.ago) }

  scope :not_favorite, ->(user) { where(:id.nin => user.favorite_channel_ids) }
  scope :today_not_favorite, ->(user) { created_today.not_favorite(user).unarchived.latest }
  scope :yesterday_not_favorite, ->(user) { created_yesterday.not_favorite(user).unarchived.latest }
  scope :last_week_not_favorite, ->(user) { created_last_week.not_favorite(user).unarchived.latest }
  scope :last_month_not_favorite_not_last_week, ->(user) { created_last_month.not_favorite(user).unarchived }
  scope :older_message_not_favorite_not_last_month, ->(user) { created_older_than_last_month.not_favorite(user).unarchived }

  after_save :update_ui

  def update_ui
    broadcast_rename if saved_change_to_name?
    broadcast_waiting_for_bot if saved_change_to_waiting_for_bot?
  end

  def commentable
    tagset || doc || upload
  end

  def commentable=(value)
    if value.is_a?(Tagset)
      self.tagset = value
    elsif value.is_a?(Upload)
      self.upload = value
    end
  end

  private

  def broadcast_rename
    Turbo::StreamsChannel.broadcast_replace_later_to(
      "channel_name_#{id}",
      target: "channel_name_#{id}",
      html: <<~HTML
        <span id="channel_name">
          #{name.truncate(30)}
        </span>
      HTML
    )
  end

  def broadcast_waiting_for_bot
    broadcast_append_to "channel_waiting_for_bot_#{id}",
                        target: "channel_waiting_for_bot_#{id}",
                        renderable: SpinnerComponent.new(active: waiting_for_bot, size: :md, color: 'text-spirit-primary')
  end

  def suppressed_turbo_broadcasts?
    false
  end
end
